@@ -1,6 +1,7 @@
 package org.tekkotsu.mon;
 
 import java.awt.*;
+import java.awt.font.*;
 import java.awt.event.*;
 import javax.swing.*;
 import javax.swing.event.*;
@@ -9,15 +10,30 @@ import java.util.*;
 import java.util.prefs.Preferences;
 import java.io.PrintWriter;
 import java.io.FileWriter;
+import javax.swing.*;
+import javax.swing.plaf.*;
+import javax.swing.plaf.basic.BasicToolTipUI;
+import javax.swing.text.*;
 
 //Admittedly a little sloppy, but I don't want to spend forever on this...
 
 public class ControllerGUI extends JFrame implements ActionListener, KeyListener, EStopListener.UpdatedListener {
+	public class MyMenu extends JList {
+		public MyMenu() { super(); }
+		// use custom tooltip to support multiple lines
+		public JToolTip createToolTip() { return new JMultiLineToolTip(); }
+	}
+	
 	org.tekkotsu.sketch.SketchGUI cameraSkGUI=null, localSkGUI=null, worldSkGUI=null;
-	JList menu;
+	MyMenu menu;
 	JScrollPane menuScroll;
 	JComboBox title;
-	JLabel status;
+	public class MyLabel extends JLabel {
+		public MyLabel(String s) { super(s); }
+		// use custom tooltip to support multiple lines
+		public JToolTip createToolTip() { return new JMultiLineToolTip(); }
+	}
+	MyLabel status;
 	JList scripts;
 	ControllerListener comm;
 	EStopListener estopComm;
@@ -68,7 +84,7 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 	final static ImageIcon rarrow = new ImageIcon("images/rarrow.gif");
 	final static ImageIcon larrow = new ImageIcon("images/larrow.gif");
 	final static ImageIcon carrows = new ImageIcon("images/chasingarrows.gif");
-
+		
 	public class MyCellRenderer implements ListCellRenderer {
 		public Component getListCellRendererComponent(JList list,Object value,int index,boolean isSelected,boolean cellHasFocus) {
 			ControllerListener.MenuEntry me=(ControllerListener.MenuEntry)value;
@@ -102,8 +118,8 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 				title.setBorder(BorderFactory.createLineBorder(Color.GRAY,1));
 			else
 				title.setBorder(BorderFactory.createEmptyBorder(1,1,1,1));
+			JComponent tmp=Box.createHorizontalBox();
 			if(me.hasSubmenu) {
-				Box tmp=Box.createHorizontalBox();
 				tmp.add(title);
 				//				tmp.add(Box.createHorizontalGlue());
 				JLabel arr=new JLabel(rarrow);
@@ -113,7 +129,6 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 					tmp.setToolTipText(me.description);
 				return tmp;
 			} else {
-				Box tmp=Box.createHorizontalBox();
 				tmp.add(title);
 				tmp.add(Box.createHorizontalStrut(rarrow.getIconWidth()));
 				if(me.description.length()!=0)
@@ -214,7 +229,7 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 						}
 					}
 					//Set focus to the main menu
-					menu.requestFocus();
+					//menu.requestFocus();
 				}
 				for(int i=0; i<scriptsModel.getSize(); i++)
 					if(scriptsModel.get(i).toString().equals("CONNECT"))
@@ -470,7 +485,7 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 		getContentPane().add(Box.createVerticalStrut(spacer_size),BorderLayout.NORTH);
 		getContentPane().add(Box.createVerticalStrut(spacer_size),BorderLayout.SOUTH);
 		
-		menu=new JList();
+		menu=new MyMenu();
 		menu.setCellRenderer(new MyCellRenderer());
 		menu.setFixedCellWidth(165);
 		menu.addMouseListener(new JListDoubleClick(this)); 
@@ -529,7 +544,7 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 				tmp2.add(Box.createHorizontalStrut(spacer_size));
 				tmp.add(tmp2,BorderLayout.WEST);
 			}
-			status=new JLabel("Connecting...");
+			status=new MyLabel("Connecting...");
 			tmp.add(status,BorderLayout.CENTER);
 			{
 				Box tmp2=Box.createHorizontalBox();
@@ -679,8 +694,8 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 				scriptsModel.addElement(new ScriptEntry(prefs.get("ControllerGUI.script"+i+".title","unknown"),prefs.get("ControllerGUI.script"+i+".cmd","")));
 		} else {
 			//uninitialized, supply some default scripts
-			scriptsModel.addElement(new ScriptEntry("Quality Video","!set vision.rawcam_transport=tcp\n!set vision.rawcam_compression=none\n!set vision.rawcam_y_skip=1\n!set vision.rawcam_uv_skip=1\n!set vision.rawcam_interval=1500"));
-			scriptsModel.addElement(new ScriptEntry("Smooth Video","!set vision.rawcam_y_skip=2\n!set vision.rawcam_uv_skip=3\n!set vision.rawcam_interval=0\n!set vision.rawcam_compression=jpeg\n!set vision.rawcam_transport=udp"));
+			scriptsModel.addElement(new ScriptEntry("Quality Video","!set vision.rawcam.transport=tcp\n!set vision.rawcam.compression=none\n!set vision.rawcam.y_skip=1\n!set vision.rawcam.uv_skip=1\n!set vision.rawcam.interval=1500"));
+			scriptsModel.addElement(new ScriptEntry("Smooth Video","!set vision.rawcam.y_skip=2\n!set vision.rawcam.uv_skip=3\n!set vision.rawcam.interval=0\n!set vision.rawcam.compression=jpeg\n!set vision.rawcam.transport=udp"));
 			scriptsModel.addElement(new ScriptEntry("Head Remote Control","!root \"TekkotsuMon\" \"Head Remote Control\""));
 			scriptsModel.addElement(new ScriptEntry("Walk Remote Control","!root \"TekkotsuMon\" \"Walk Remote Control\""));
 		}
@@ -782,3 +797,116 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
   public void keyTyped(KeyEvent e) { }
 }
 
+//multi line tooltips from Zafir Anjum http://www.codeguru.com/java/articles/122.shtml
+class JMultiLineToolTip extends JToolTip {
+	private static final String uiClassID = "ToolTipUI";
+	
+	String tipText;
+	JComponent component;
+	
+	public JMultiLineToolTip() { updateUI(); }
+	public void updateUI() { setUI(MultiLineToolTipUI.createUI(this)); }
+	
+	public int getColumns() { return columns; }
+	public void setColumns(int columns) {
+		this.columns = columns;
+		this.fixedwidth = 0;
+	}
+	
+	public int getFixedWidth() { return fixedwidth; }
+	public void setFixedWidth(int width) {
+		this.fixedwidth = width;
+		this.columns = 0;
+	}
+	
+	protected int columns = 0;
+	protected int fixedwidth = 0;
+}
+
+class MultiLineToolTipUI extends BasicToolTipUI {
+	static MultiLineToolTipUI sharedInstance = new MultiLineToolTipUI();
+	Font smallFont; 			     
+	JToolTip tip;
+	protected CellRendererPane rendererPane;
+	private JTextArea textArea ;
+	
+	public static ComponentUI createUI(JComponent c) {
+		return sharedInstance;
+	}
+	
+	public MultiLineToolTipUI() {
+		super();
+		textArea = new JTextArea();
+		smallFont = new Font("sanserif",0,11);
+	}
+	
+	public void installUI(JComponent c) {
+		super.installUI(c);
+		tip = (JToolTip)c;
+		rendererPane = new CellRendererPane();
+		c.add(rendererPane);
+	}
+	
+	public void uninstallUI(JComponent c) {
+		super.uninstallUI(c);
+		c.remove(rendererPane);
+		rendererPane = null;
+	}
+	
+	public void paint(Graphics g, JComponent c) {
+		String tipText = ((JToolTip)c).getTipText();
+		textArea.setText(tipText );
+		textArea.setFont(smallFont);
+		textArea.setMargin(new Insets(4,6,4,6));
+		Dimension size = c.getSize();
+		textArea.setBackground(c.getBackground());
+		rendererPane.paintComponent(g, textArea, c, 1, 1, size.width - 1, size.height - 1, true);
+	}
+	
+	public Dimension getPreferredSize(JComponent c) {
+		String tipText = ((JToolTip)c).getTipText();
+		if (tipText == null)
+			return new Dimension(0,0);
+		textArea.setText(tipText );
+		textArea.setFont(smallFont);
+		textArea.setMargin(new Insets(4,6,4,6));
+		rendererPane.removeAll();
+		rendererPane.add(textArea );
+		textArea.setWrapStyleWord(true);
+		int width = ((JMultiLineToolTip)c).getFixedWidth();
+		int columns = ((JMultiLineToolTip)c).getColumns();
+		
+		if( columns > 0 )
+		{
+			textArea.setColumns(columns);
+			textArea.setSize(0,0);
+			textArea.setLineWrap(true);
+			textArea.setSize( textArea.getPreferredSize() );
+		}
+		else if( width > 0 )
+		{
+			textArea.setLineWrap(true);
+			Dimension d = textArea.getPreferredSize();
+			d.width = width;
+			d.height++;
+			textArea.setSize(d);
+		}
+		else
+			textArea.setLineWrap(false);
+		
+		Dimension dim = textArea.getPreferredSize();
+		
+		dim.height += 1;
+		dim.width += 1;
+		return dim;
+	}
+	
+	public Dimension getMinimumSize(JComponent c) {
+		return getPreferredSize(c);
+	}
+	
+	public Dimension getMaximumSize(JComponent c) {
+		return getPreferredSize(c);
+	}
+}
+
