@@ -1,17 +1,22 @@
 package org.tekkotsu.mon;
 
+//'Joints' is something of a misnomer -- also stores sensor and button information as well
 public class Joints {
+	public String model;
   public float[] positions;
   public float[] duties;
   public float[] sensors;
   public float[] buttons;
-  int timestamp;
+  public long timestamp;
+	public long frame;
 
   Joints() {
-      //note: this is old and for the ers2xx, but, eh. doesn't hurt to leave like this
+		//note: this is old and for the ers2xx, but, eh. doesn't hurt to leave like this
+		//each packet holds correct number of items for each category, so these
+		//can be reassigned with the correct number of items for the model in question
     positions=new float[18];
     duties=new float[18];
-    sensors=new float[6];
+    sensors=new float[10];
     buttons=new float[8];
   } 
 
