@@ -38,8 +38,7 @@ public abstract class TCPListener extends Listener {
 			if(_isConnected) {
 				connected(_socket);
 				if(!destroy)
-					System.out.println("["+_port+"] disconnected");
-          System.out.println("["+_port+"] attempting to reestablish ..");
+					System.out.println("["+_port+"] disconnected, attempting to reestablish ..");
 			}
 			attempts++;
 			if(destroy) {
@@ -55,9 +54,9 @@ public abstract class TCPListener extends Listener {
 	public void close() {
 		_listenerThread=null;
 		_isConnected=false;
-		try { _socket.close(); } catch (Exception ex) { }
+		try { _socket.close(); } catch (Exception ex) {System.out.println("Got exception during closing socket "+ex); }
 		if (_isServer)
-			try { _serverSocket.close(); } catch (Exception ex) { }
+			try { _serverSocket.close(); } catch (Exception ex) {System.out.println("Got exception during closing server socket "+ex); }
 	}
 
 	public TCPListener() { super(); }
@@ -67,3 +66,4 @@ public abstract class TCPListener extends Listener {
 	Socket _socket;
 	ServerSocket _serverSocket;
 }
+
