@@ -98,17 +98,22 @@ public class LineShapeInfo extends ShapeInfo {
 	    } else {
 		e2xi = 10000; e2yi = (int)(e2xi*m+b);
 	    };
+	    graphics.setStroke(new BasicStroke(1.0f));
 	    graphics.drawLine(e1xi,e1yi,e2xi,e2yi);
-	final float dl = 5/scaling;
-	if (end1_valid)
-	    graphics.drawLine((int) (e1xi+dl*Math.cos(theta)+.5),(int) (e1yi+dl*Math.sin(theta)+.5),
-			      (int) (e1xi-dl*Math.cos(theta)+.5),(int) (e1yi-dl*Math.sin(theta)+.5));
-	    //	    graphics.fillOval((int)e1x-radius/2, (int)e1y-radius/2, radius, radius);
-	if (end2_valid)
-	    graphics.drawLine((int) (e2xi+dl*Math.cos(theta)+.5),(int) (e2yi+dl*Math.sin(theta)+.5),
-			      (int) (e2xi-dl*Math.cos(theta)+.5),(int) (e2yi-dl*Math.sin(theta)+.5));
-	//	    graphics.fillOval((int)e2x-radius/2, (int)e2y-radius/2, radius, radius);
-
+	    final float dl = 5/scaling;
+	    if (end1_valid) {
+		int v1xi = (int)e1x, v1yi = (int)e1y;
+		graphics.drawLine((int)(v1xi+dl*Math.cos(theta)+.5), (int)(v1yi+dl*Math.sin(theta)+.5),
+				  (int)(v1xi-dl*Math.cos(theta)+.5), (int)(v1yi-dl*Math.sin(theta)+.5));
+		//	    graphics.fillOval((int)v1x-radius/2, (int)v1y-radius/2, radius, radius);
+	    }
+	    if (end2_valid) {
+		int v2xi = (int)e2x, v2yi = (int)e2y;
+		graphics.drawLine((int)(v2xi+dl*Math.cos(theta)+.5), (int)(v2yi+dl*Math.sin(theta)+.5),
+				  (int)(v2xi-dl*Math.cos(theta)+.5), (int)(v2yi-dl*Math.sin(theta)+.5));
+		//	    graphics.fillOval((int)e2x-radius/2, (int)e2y-radius/2, radius, radius);
+	    }
+	    
 	// draw circles for variance
 	// graphics.drawOval((int)e1x,(int)e1y,(int)(e1v/2),(int)(e1v/2));
 	// graphics.drawOval((int)e2x,(int)e2y,(int)(e2v/2),(int)(e2v/2));
